@@ -366,7 +366,7 @@ def get_b2c_delivery_events(delivery_order):
         lambda x: (x['status'] == 15 and 'b2c_delivery_actual' in x['info']) or
                     x['status'] == 18 or
                     x['status'] == 19 or
-                    x['status'] in [29, 35, 36],
+                    x['status'] in DELIVERY_ORDER_REJECTED_STATUSES,
         delivery_order['events_info']
     )
     
@@ -570,6 +570,9 @@ class DeliveryOrderClient(EntityClientBase):
 
     def delivery_courier_receive(self, id, event_info, pasync=True):
         return self.http_post_json(self.entity_endpoint_base_url + "{0}/_delivery-courier-receive".format(id), event_info)
+    
+    def pickup_receive(self, id, event_info, status):
+        return self.http_post_json(self.entity_endpoint_base_url + "{0}/_pickup-receive".format(id), {'event_info': event_info, 'status': status})
     # endregion
 
     def search_batch(self, search_info):
